import {
  UserLayout,
  BasicLayout,
  PageView
} from '@/layouts'

export const asyncRouterMap = [{
  path: '/',
  name: 'index',
  component: BasicLayout,
  meta: {
    title: '首页'
  },
  redirect: '/home',
  children: [{
    path: '/home',
    name: 'home',
    redirect: '/home',
    component: PageView,
    meta: {
      title: '首页',
      icon: 'home'
    },
    hideChildrenInMenu: true,
    children: [{
      path: '/home',
      name: 'home',
      component: () => import(/* webpackChunkName: "home" */ '@/views/Home'),
      meta: {
        title: '首页',
        icon: 'home',
        hidden: true
      }
    },
    {
      path: '/changePwd',
      name: 'changePwd',
      component: () => import(/* webpackChunkName: "home" */ '@/views/user/ChangePwd'),
      meta: {
        title: '修改密码',
        icon: 'home',
        hidden: true
      }
    }
    ]
  },
  // 考评管理
  {
    path: '/evaluation',
    redirect: '/evaluation/evaluationItem',
    component: PageView,
    meta: {
      title: '考评管理',
      icon: 'block',
	  permission: 'M_evaluation_0'
    },
    children: [{
      path: '/evaluation/evaluationItem',
      name: 'EvaluationItem',
      component: () => import(/* webpackChunkName: "evaluation" */
        '@/views/evaluation/evaluationItem/EvaluationItem.vue'),
      meta: {
        title: '考评项目',
        icon: 'save',
        permission: 'M_evaluationItem_list'
      }
    }, {
      path: '/evaluation/evaluationPlan',
      name: 'EvaluationPlan',
      component: () => import(/* webpackChunkName: "evaluation" */
        '@/views/evaluation/evaluationPlan/EvaluationPlan.vue'),
      meta: {
        title: '考评方案',
        icon: 'switcher',
        permission: 'M_evaluationPlan_list'
      }
    }]
  },
  // 基础设置 BasicSettings
  {
    path: '/BasicSettings',
    redirect: '/BasicSettings/Organization',
    component: PageView,
    meta: {
      title: '基础设置',
      icon: 'apartment',
      permission: 'M_basicSettings_0'
    },
    children: [{
      path: '/BasicSettings/Organization',
      name: 'Organization',
      component: () => import(/* webpackChunkName: "auth" */ '@/views/BasicSettings/Organization.vue'),
      meta: {
        title: '组织机构',
        icon: 'user',
        permission: 'M_basicSettings_organization'
      }
    },
    {
      path: '/BasicSettings/StoreManagement',
      name: 'StoreManagement',
      component: () => import(/* webpackChunkName: "auth" */ '@/views/BasicSettings/StoreManagement.vue'),
      meta: {
        title: '门店管理',
        icon: 'user',
        permission: 'M_basicSettings_store'
      }
    }
    ]
  },
  {
    path: '/auth',
    redirect: '/auth/userList',
    component: PageView,
    meta: {
      title: '运营权限管理',
      icon: 'wallet',
      permission: 'M_power_0'
    },
    children: [{
      path: '/auth/userList',
      name: 'powerUserList',
      component: () => import(/* webpackChunkName: "auth" */ '@/views/power/user/userList.vue'),
      meta: {
        title: '用户管理',
        icon: 'user',
        permission: 'M_power_user'
      }
    },
    {
      path: '/auth/roleList',
      name: 'powerRoleList',
      component: () => import(/* webpackChunkName: "auth" */ '@/views/power/role/roleList.vue'),
      meta: {
        title: '角色管理',
        icon: 'solution',
        permission: 'M_power_role'
      }
    }
    ]
  },
  {
    path: '/SupervisionAuth',
    redirect: '/SupervisionAuth/userList',
    component: PageView,
    meta: {
      title: '督导权限管理',
      icon: 'wallet',
      permission: 'M_supervision_0'
    },
    children: [{
      path: '/SupervisionAuth/userList',
      name: 'SupervisionUserList',
      component: () => import(/* webpackChunkName: "CardVoucherAuth" */ '@/views/SupervisionAuth/user/userList.vue'),
      meta: {
        title: '用户管理',
        icon: 'user',
        permission: 'M_supervision_user'
      }
    },
    {
      path: '/SupervisionAuth/roleList',
      name: 'SupervisionRoleList',
      component: () => import(/* webpackChunkName: "CardVoucherAuth" */ '@/views/SupervisionAuth/role/roleList.vue'),
      meta: {
        title: '角色管理',
        icon: 'solution',
        permission: 'M_supervision_role'
      }
    }
    ]
  }
  ]
},
{
  path: '*',
  redirect: '/404',
  hidden: true
}
]

/**
 * 基础路由
 * @type { *[] }
 */
export const constantRouterMap = [{
  path: '/user',
  component: UserLayout,
  redirect: '/user/login',
  hidden: true,
  children: [{
    path: 'login',
    name: 'login',
    component: () => import(/* webpackChunkName: "user" */ '@/views/user/Login')
  },
  {
    path: 'register',
    name: 'register',
    component: () => import(/* webpackChunkName: "user" */ '@/views/user/Register')
  },
  {
    path: 'register-result',
    name: 'registerResult',
    component: () => import(/* webpackChunkName: "user" */ '@/views/user/RegisterResult')
  },
  {
    path: 'recover',
    name: 'recover',
    component: undefined
  }
  ]
},
{
  path: '/404',
  component: () => import(/* webpackChunkName: "fail" */ '@/views/exception/404')
}

]
